Struct
QmiMessageNasIncrementalNetworkScanOutput
since: 1.38
Description [src]
struct QmiMessageNasIncrementalNetworkScanOutput {
/* No available fields */
}
The QmiMessageNasIncrementalNetworkScanOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Instance methods
qmi_message_nas_incremental_network_scan_output_get_result
Get the result of the QMI operation.
since: 1.38
qmi_message_nas_incremental_network_scan_output_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_message_nas_incremental_network_scan_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38